@@ -27,7 +27,7 @@
 #include "k3bthreadjob.h"
 #include "k3b_i18n.h"
 
-#include <QtCore/QDebug>
+#include <QDebug>
 
 
 class K3b::AudioCueFileWritingJob::Private
