@@ -18,7 +18,7 @@
 #include "k3bdatadoc.h"
 #include "k3bdiritem.h"
 #include "k3bisooptions.h"
-#include <QtCore/QList>
+#include <QList>
 
 namespace K3b {
 
